#version 150

#moj_import <light.glsl>
#moj_import <fog.glsl>

in vec3 Position;
in vec4 Color;
in vec2 UV0;
in ivec2 UV2;
in vec3 Normal;

uniform sampler2D Sampler2;
uniform sampler2D Sampler0;
uniform float GameTime;

uniform mat4 ModelViewMat;
uniform mat4 ProjMat;
uniform vec3 ChunkOffset;
uniform int FogShape;

out float vertexDistance;
out vec4 vertexColor;
out vec2 texCoord0;
out vec4 normal;

#define pi 3.1415926535897932

void main() {
    vec3 position = Position / 2.0 * pi;
	
	vec3 pos = Position + ChunkOffset;
    float animation = GameTime * 4000.0;
	float wind      = GameTime *  300.0;

    float m0 = distance(Position.xz, vec2(8.0, 8.0)) * 10.0;
	float alpha = texture(Sampler0, UV0).a * 255.0;
	vec4 shakePos = vec4(0.0, 0.0, 0.0, 0.0);
	vertexColor = Color * minecraft_sample_lightmap(Sampler2, UV2);
	
    if ((alpha == 253.0 || alpha == 0.0 || alpha == 255.0) && Color.r < Color.b) { // water
        shakePos.x = (sin(position.x + animation) * cos(wind)) / 32.0;
        shakePos.y = (cos(m0         + animation) * 0.75     ) / 28.0;
        shakePos.z = (cos(position.z + animation) * sin(wind)) / 32.0;
		
    } else if (alpha == 252.0) { // portal
	    vec3 absNormal = abs(Normal);
	    if (absNormal.z > absNormal.x && absNormal.z > absNormal.y) shakePos.z = (sin(position.x + animation) + cos(m0 + animation) * 0.65) / 24.0; // North/South wobble
        if (absNormal.x > absNormal.z && absNormal.x > absNormal.y) shakePos.x = (cos(position.z + animation) + sin(m0 + animation) * 0.65) / 24.0; // East / West wobble
		
    }
    
	gl_Position = ProjMat * ModelViewMat * (vec4(pos, 1.0) + shakePos);
	
    vertexDistance = fog_distance(ModelViewMat, pos, FogShape);
	vertexColor = Color * minecraft_sample_lightmap(Sampler2, UV2);
    texCoord0 = UV0;
    normal = ProjMat * ModelViewMat * vec4(Normal, 0.0);
}
